@@ -29,7 +29,7 @@ class CipherExecutable(Executable):
 
 class CipherUnit(Unit, metaclass=CipherExecutable, abstract=True):
 
-    def __init__(self, key, **keywords):
+    def __init__(self, key: arg.help('The encryption key.'), **keywords):
         super().__init__(key=key, **keywords)
 
     @property
@@ -125,7 +125,6 @@ class BlockCipherUnitBase(CipherUnit, abstract=True):
                 return unpad(result, self.blocksize, p.lower())
             except Exception:
                 pass
-        self.output(self.args.padding)
         raise RefineryPartialResult(
             'None of these paddings worked: {}'.format(', '.join(self.args.padding)),
             partial=result)
