@@ -25,15 +25,14 @@ class EndOfStringNotFound(ValueError):
 
 class PathExtractorUnit(Unit):
 
-    def interface(self, argp):
-        argp.add_argument('paths', metavar='path', nargs='*', default=['*'], type=pathspec,
-            help=(
-                'A path from which data is to be extracted. Each item is returned '
-                ' as a separate output of this unit. Paths may contain wildcards. '
-                'The default is a single asterix, which means that every item will '
-                'be extracted.'
-            )
-        )
+    @classmethod
+    def interface(cls, argp):
+        argp.add_argument('paths', metavar='path', nargs='*', default=['*'], type=pathspec, help=(
+            'A path from which data is to be extracted. Each item is returned '
+            ' as a separate output of this unit. Paths may contain wildcards. '
+            'The default is a single asterix, which means that every item will '
+            'be extracted.'
+        ))
         return super().interface(argp)
 
     def _check_reachable(self, path: str) -> bool:
@@ -49,7 +48,8 @@ class PathExtractorUnit(Unit):
 
 class MemoryExtractorUnit(Unit):
 
-    def interface(self, argp):
+    @classmethod
+    def interface(cls, argp):
         limit = argp.add_mutually_exclusive_group()
         limit.add_argument('-t', '--take', type=number[1:], default=0,
             help='The number of bytes to read.')
@@ -68,7 +68,7 @@ class MemoryExtractorUnit(Unit):
         start, end = offset_oracle(self.args.offset)
 
         if self.args.end:
-            end = offset_oracle(self.args.end)
+            end, _ = offset_oracle(self.args.end)
             if end < start:
                 raise ValueError(
                     F'The end offset 0x{end:08X} lies {start-end} bytes '
